
class MEDIA:
    ROOT_IMG = "/images"
    GOLF_COURSE_LOGO = ROOT_IMG+"/golf-courses/logo/{}"
    GOLF_COURSE_BG = ROOT_IMG+"/golf-courses/background/{}"
    USER_PROFILE = ROOT_IMG+"/users/profile/{}"


class Resource:
    GW_USER = "gw_user"
    GW_HOLE = "hole"
    GW_SENSOR = "sensor"
    GW_GOLF_COURSE = "golf_course"
    GW_ALERT = "alert"
    GW_MENU = "menu"
    GW_REPORT = "report"
